@@ -3,7 +3,7 @@
 #
 
 import os, sys, socket, re, time, smtplib, calendar, StringIO, logging, logging.handlers, locale, gzip
-import urllib, urllib2
+import urllib, urllib2, urlparse
 from datetime import datetime, timedelta
 import email
 from email.Utils import parseaddr, formataddr, formatdate
@@ -68,11 +68,18 @@ def check_mail_config(job):
         job['mail']=mail
 
     magikmon=job.get('magikmon', '')
-    if magikmon and not url_re.match(magikmon):
-        errors['magikmon']='not a valid URL'
-        
+    if magikmon:
+        if not url_re.match(magikmon):
+            errors['magikmon']='not a valid URL'
+        else:
+            if job['program']=='esxmon':
+                up=urlparse.urlparse(magikmon)
+                if up[1].lower().startswith('monitoring.magikmon.com') and up[2].lower().startswith('/sendbackup'):
+                    magikmon=''
+                    # don't send esxmon status to MagiKmon backup service 
+                    # errors['magikmon']='Cannot report status to MagikMon backup service'
+                    
     job['magikmon']=magikmon
-
     
     if mail:
         try:
@@ -127,9 +134,15 @@ def check_mail_config(job):
         else:
             recipients=recipients.split()
             bad=[]
-            for recipient in recipients:
+            for recipient in recipients[:]:
                 if not email_addressRE.match(recipient):
                     bad.append(recipient)
+                domain=recipient.split('@')[-1].lower()
+                if job['program']=='esxmon' and  domain=='monitoring.magikmon.com':
+                    # don't send esxmon status to MagiKmon backup service 
+                    # errors['recipients']='Cannot report status to MagikMon backup service'
+                    recipients.remove(recipient)
+                    
             if bad:
                 errors['recipients']='invalid email addresses: %s' % ' '.join(bad)
             else:
