@@ -443,7 +443,7 @@ class Ghettovcb(Archiver):
                 break
                                            
             if protocol=='ftp':
-                ftp_line='ftpput -P %s -u "%s" -p "%s" %s %s %s' % (con['port'], con['username'], con['password'], con['host'], destination, source)
+                ftp_line='ftpput -P %s -u "%s" -p "%s" %s "%s" "%s"' % (con['port'], con['username'], con['password'], con['host'], destination, source)
                 self.log.info('start upload of "%s" to "%s"', source, destination)
                 cmd_line=self.hide_password(ftp_line)
                 self.log.debug('ftp command: %s', cmd_line)
@@ -626,7 +626,7 @@ class Ghettovcb(Archiver):
             else:
                 for filename in output.split('\n'):
                     filename=filename.strip()
-                    if filename and filename not in self.uploaded_filenames:
+                    if filename and not filename.startswith('.lck-') and filename not in self.uploaded_filenames:
                         self.uploaded_filenames[filename]=None
                         relfilename=filename[len(root_backup_dir):]
                         relfilename=relfilename.lstrip('/')
