@@ -216,10 +216,19 @@ class MyFormatter(logging.Formatter):
 # Parse the command line
 #
 def main():
+
+    if len(sys.argv)>1 and sys.argv[1]=='ftp':
+        args=sys.argv[:]
+        args.remove('ftp')
+        import ftpd
+        ftpd.ftpmain(args)
+        sys.exit(0)
     
     parser=parser=OptionParser(version='%%prog %s' % __version__ )
     parser.set_usage('%prog [options] command [job..]\n\n'
-                      '\tcommand in "backup", "check", "checkmail"')
+                     '\tcommand in "backup", "check", "checkmail"\n\n'
+                     '\tuse "ftp" in first place to start buil-in ftp server,\n'
+                     '\tuse "ftp -h" in this order for more')
     
     parser.add_option("-c", "--config", dest="config", default='mksbackup.ini', help="use another ini file", metavar="configfile")
     parser.add_option("-d", "--debug", dest="debug", action="store_true", default=False, help="switch to debug level, increase verbosity")
@@ -274,6 +283,7 @@ def main():
         parser.error('invalid command "%s"' % command)
     
     command=command.lower()
+    
     if command=='backup':
         command_display='BACKUP'
     else:
@@ -507,9 +517,14 @@ def main():
                         ty=typ
                     msg_body+='    %s %-12s %s\n' % (today.strftime('%a %d %b %Y'), ty, target)
                     log.info('    %s %-12s %s', today.strftime('%a %d %b %Y'), ty, target)
-                    if typ!='none' and typ!=None and not os.path.isdir(os.path.dirname(target)):
-                        msg_body+='        directory not found !!!\n'
-                        log.warning('        directory not found: %s', os.path.dirname(target))
+
+                    if typ!='none' and typ!=None:
+                        if target.startswith('ftp://'):
+                            msg_body+='      ftp directory not tested\n'
+                            log.info('       ftp directory not tested: %s', target)
+                        elif not os.path.isdir(os.path.dirname(target)):
+                            msg_body+='        directory not found !!!\n'
+                            log.warning('        directory not found: %s', os.path.dirname(target))
                         
             msg_body='%s\n\n%s\n' % (msg_body, extra)
             if job['mail'] and command=='checkmail':
