@@ -177,16 +177,16 @@ class Wbadmin(Archiver):
         wba_del_process=None           
         if self.name=='wbadminsys' and self.keepversions:
             wba_del_args=[ self.exe, 'delete', 'systemstatebackup', '-quiet', '-keepVersions:%d'%(self.keepversions-1,), '-backupTarget:%s' % ( self.target, ), '-machine:%s' % ( self.machine, ),   ]
-            log.info('run: %s', ' '.join(wba_del_args))
+            log.info('run: %s', self.hide_password(' '.join(wba_del_args)))
             try:
                 wba_del_process=subprocess.Popen(param_encode(wba_del_args, manager.default_encoding), executable=self.wbadmin_bin, stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
                 wba_del_out, wba_del_err=wba_del_process.communicate()
             except Exception, e:
-                log.error('Unexpected exception running command: %s', self.hide_password(' '.join(self.wba_del_args)))
+                log.error('Unexpected exception running command: %s', self.hide_password(' '.join(wba_del_args)))
                 raise
             else:
                 if wba_del_process.returncode!=0:
-                    log.error('Error code=%d running command: %s', wba_del_process.returncode, self.hide_password(' '.join(self.wba_del_args)))
+                    log.error('Error code=%d running command: %s', wba_del_process.returncode, self.hide_password(' '.join(wba_del_args)))
             time.sleep(2)
         
         start2=int(time.time())
